==> dnet-index-proxy-0.0.5.tgz: package/lib/dnet-index-proxy/proxy.js <==
#!/usr/bin/env node

var connect = require("connect");
var http = require("http");
var querystring = require("querystring");
var parse = require('url').parse;

var thrift = require('mmikulicic-thrift'),
//    ttransport = require("thrift/lib/thrift/transport.js"),
    //ttransport = require('thrift/transport');
    IndexService = require('./gen-nodejs/IndexService'),
    ttypes = require('./gen-nodejs/index_types');

//var connection = thrift.createConnection("localhost", 9090, {transport: ttransport.TBufferedTransport}),
var connection = thrift.createConnection("localhost", 9090),
//var connection = thrift.createConnection("node2.p.efg", 9090),
    client = thrift.createClient(IndexService, connection);

function indexLookup(req, res, next) {
    var p = querystring.parse(parse(req.url).query)
    
    client.indexLookup(p.id, p.query, p.mdformat, p.layout, function(err, response) {
        res.writeHead(200, {"Content-Type": "text/xml; charset=utf-8"});
        if(err) 
            res.end(err.why);
        else
            res.end(response);
    });
}

function getNumberOfElements(req, res, next) {
    var p = querystring.parse(parse(req.url).query)

    client.getNumberOfElements(p.rsId, function(err, response) {
        res.writeHead(200, {"Content-Type": "text/xml; charset=utf-8"});
        res.end(response);
    });
};

function getResult(req, res, next) {
    var p = querystring.parse(parse(req.url).query)

    client.getResult(p.rsId, p.fromPosition, p.toPosition, function(err, response) {
        res.writeHead(200, {"Content-Type": "text/xml; charset=utf-8"});
        res.end(response);
    });
};

connect(
    connect.router(function(app) {
        app.get('/IndexService/indexLookup',  indexLookup);
        app.get('/resultSet/getNumberOfElements', getNumberOfElements);
        app.get('/resultSet/getResult', getResult);

        app.get('/:context/services/IndexService/indexLookup',  indexLookup);
        app.get('/:context/services/resultSet/getNumberOfElements', getNumberOfElements);
        app.get('/:context/services/resultSet/getResult', getResult);

        app.get('/:context/mvc/directindex.do/IndexService/indexLookup',  indexLookup);
        app.get('/:context/mvc/directindex.do/getNumberOfElements', getNumberOfElements);
        app.get('/:context/mvc/directindex.do/getResult', getResult);

    })
).listen(3000);

==> dnet-index-proxy-0.0.6.tgz: package/lib/dnet-index-proxy/proxy.js <==
#!/usr/bin/env node

var connect = require("connect");
var http = require("http");
var querystring = require("querystring");
var parse = require('url').parse;

var thrift = require('mmikulicic-thrift'),
//    ttransport = require("thrift/lib/thrift/transport.js"),
    //ttransport = require('thrift/transport');
    IndexService = require('./gen-nodejs/IndexService'),
    ttypes = require('./gen-nodejs/index_types');

//var connection = thrift.createConnection("localhost", 9090, {transport: ttransport.TBufferedTransport}),
var connection = thrift.createConnection("localhost", 9090),
//var connection = thrift.createConnection("node2.p.efg", 9090),
    client = thrift.createClient(IndexService, connection);

function reply(res) {
    return function(err, response) {
        res.writeHead(200, {"Content-Type": "text/xml; charset=utf-8"});
        if(err) 
            res.end(err.why);
        else
            res.end(response);
    }
}

function params(req) {
    return querystring.parse(parse(req.url).query);
}

function indexLookup(req, res, next) {
    var p = querystring.parse(parse(req.url).query)
    
    client.indexLookup(p.id, p.query, p.mdformat, p.layout, reply(res));
}

function getBrowsingStatistics(req, res, next) {
    var p = params(req);
    
    client.getBrowsingStatistics(p.query, p.index, p.mdformat, p.layout, reply(res));
}


function getNumberOfElements(req, res, next) {
    var p = params(req);

    client.getNumberOfElements(p.rsId, reply(res));
};

function getResult(req, res, next) {
    var p = params(req);

    client.getResult(p.rsId, p.fromPosition, p.toPosition, reply(res));
};

connect(
    connect.router(function(app) {
        app.get('/IndexService/indexLookup',  indexLookup);
        app.get('/IndexService/getBrowsingStatistics',  getBrowsingStatistics);
        app.get('/resultSet/getNumberOfElements', getNumberOfElements);
        app.get('/resultSet/getResult', getResult);

        app.get('/:context/services/IndexService/indexLookup',  indexLookup);
        app.get('/:context/services/IndexService/getBrowsingStatistics',  getBrowsingStatistics);
        app.get('/:context/services/resultSet/getNumberOfElements', getNumberOfElements);
        app.get('/:context/services/resultSet/getResult', getResult);

        app.get('/:context/mvc/directindex.do/IndexService/indexLookup',  indexLookup);
        app.get('/:context/mvc/directindex.do/IndexService/getBrowsingStatistics',  getBrowsingStatistics);
        app.get('/:context/mvc/directindex.do/getNumberOfElements', getNumberOfElements);
        app.get('/:context/mvc/directindex.do/getResult', getResult);

    })
).listen(3000);
